export declare namespace APITypes {
    type TokenResponse = {
        token?: string;
    };
    type WebSocketSubscriptionTokensResponse = {
        data: {
            tokens: {
                token: string;
                channel: string;
            }[];
        };
    };
    type AuthResponse = {
        accessToken: string;
        refreshToken: string;
        expiresAt: number;
    };
    type RefreshedTokenResponse = {
        expires_in: number;
        refresh_token: string;
        access_token: string;
    };
    type TBlogResponse = {
        publicWebSocketChannel: string;
        owner: TUser;
        blogUrl: string;
    };
    type TSmilesResponse = {
        data: {
            sets: TSmilesSet[];
        };
    };
    type TSmilesSet = {
        type: string;
        smiles: TSmile[];
    };
    type TBadge = {
        achievement: {
            name: string;
            type: string;
        };
        id: string;
        isCreated: boolean;
        largeUrl: string;
        mediumUrl: string;
        smallUrl: string;
        name: string;
    };
    type TRole = {
        id: string;
        name: string;
        smallUrl: string;
        largeUrl: string;
        mediumUrl: string;
        priority: number;
    };
    type TAuthor = {} & TUser;
    type TUser = {
        badges: TBadge[];
        roles: TRole[];
        createdAt: number;
        isOwner: boolean;
        isVerifiedStreamer: boolean;
        vkplayProfileLink: string;
        isChatModerator: boolean;
        displayName: string;
        id: number;
        name: string;
        hasAvatar: boolean;
        avatarUrl: string;
        nick: string;
        nickColor: number;
    };
    type TMessageBlockText = {
        content: string;
        modificator: string;
        type: "text" | string;
    };
    type TMessageBlockMention = {
        displayName?: string;
        name?: string;
        nick?: string;
        id: number;
        type: "mention";
    };
    type TMessageBlockLink = {
        content: string;
        explicit: boolean;
        type: "link";
        url: string;
    };
    type TContentParsed = [string, "unstyled" | string, []];
    type TSmile = {
        smallUrl?: string;
        mediumUrl?: string;
        largeUrl?: string;
        isAnimated?: boolean;
        id: string;
        name: string;
    };
    type TMessageBlockSmile = {
        type: "smile";
    } & TSmile;
    type TMessageBlock = TMessageBlockText | TMessageBlockSmile | TMessageBlockMention | TMessageBlockLink;
    type TParentMessage = {
        isPrivate: boolean;
        data: TMessageBlock[];
        createdAt: number;
        author: TAuthor;
        id: number;
    };
    type TMessageResponse = {
        author: TAuthor;
        createdAt: number;
        data: TMessageBlock[];
        id: number;
        style: unknown[];
        user: TUser;
        isPrivate: boolean;
        parent?: TParentMessage;
    };
    type TNewMessage = {
        channel: string;
        data: {
            data: {
                data: TMessageResponse;
                type: "message" | string;
            };
            offset: number;
        };
    };
    type ConnectionResponse = {
        client: string;
        version: string;
        expires: boolean;
        ttl: number;
    };
    type WsMessage<T> = {
        id: number;
        result: T;
    };
    type UserStat = {
        giftsCount: number;
        messagesCount: number;
        permanentBansCount: number;
        temporaryBansCount: number;
    };
    type SubscriberInfo = {
        paidSubscriptionDaysDuration: number | null;
        subscriptionDaysDuration: number | null;
    };
    type UserStatResponse = {
        bans: [];
        blog: null;
        moderator: null;
        stat: UserStat;
        subscriberInfo: SubscriberInfo;
        user: TUser;
    };
    type ChannelRoleResponse = {
        data: {
            roles: TRole[];
        };
    };
    type AccessRestrictions = {
        view: View;
    };
    type View = {
        allowed: boolean;
    };
    type CategoryType = "game" | "irl";
    type Category = {
        showPlayGameUrl?: string;
        coverUrl: string;
        type?: CategoryType;
        id: string;
        title: string;
    };
    type Count = {
        likes: number;
        viewers: number;
        views: number;
    };
    type SubscriptionLevel = {
        externalId: number;
        name: string;
        isArchived: boolean;
        isDeleted: boolean;
        id: string;
        priority: number;
        bonusMultiplier?: number;
    };
    type ProfileLink = {
        link: string;
        type: string;
    };
    type WsLimitedChannel = {
        token: string;
        channel: string;
    };
    type Stream = {
        wsChatChannel: string;
        channelCoverImageUrl: string;
        isBlackListedByUser: boolean;
        isPublic: boolean;
        user: TUser;
        accessRestrictions: AccessRestrictions;
        plannedAt: number;
        endTime: number | null;
        isChannelModerator: boolean;
        hasAccess: boolean;
        isChatModerator: boolean;
        isEnded: boolean;
        data: unknown[];
        isOnline: boolean;
        count: Count;
        isLiked: boolean;
        subscriptionLevels: SubscriptionLevel[];
        isSupportProgramMember: boolean;
        title: string;
        wsLimitedChannel: WsLimitedChannel;
        hasChatPinnedMessage: boolean;
        createdAt: number;
        daNick: string;
        category: Category;
        embedUrl: string;
        isHidden: boolean;
        channelCoverType: string;
        isCreated: boolean;
        id: string;
        wsStreamViewersChannel: string;
        wsStreamChannelPrivate: string;
        wsStreamChannel: string;
        previewUrl: string;
        wsChatChannelPrivate: string;
        titleData: TMessageBlock[];
        hasChat: boolean;
    };
    type ManageStreamResponse = {
        data: {
            stream: Stream;
        };
    };
    type Extra = {
        isLast: boolean;
        offset: number;
    };
    type CategoryResponse = {
        data: Category[];
        extra: Extra;
    };
    type CategoryFilters = {
        search: string;
        type: CategoryType;
        limit: number;
    };
    type CantSendError = {
        error: "cant_send";
        data: {
            reasons: {
                type: "slow_mode_cooldown";
                remaningTime: number;
            }[];
        };
    };
    type Reaction = {
        type: string;
        count: number;
    };
    type PinSettings = {
        messageId: number;
        reactable: boolean;
        kind: "permanent" | "stream";
    };
    type PinMessage = {
        writtenAt: number;
        reactable: boolean;
        author: TUser;
        pinner: TUser;
        id: number;
        data: TMessageBlock[];
        period: null;
        reactions: Reaction[];
        kind: "permanent" | "stream";
        reacted: string | null;
        createdAt: number;
    };
    type PinMessageResponse = {
        data: {
            pinnedMessage: PinMessage;
        };
    };
}
//# sourceMappingURL=api.d.ts.map